@@ -28,7 +28,6 @@ from django.core.urlresolvers import reverse
 from django import http
 from django import shortcuts
 from django.utils import decorators as django_dec
-from django.utils import html
 from django.utils import http as http_utils
 from django.utils.translation import ugettext_lazy as _
 from django.views.generic import list as list_view
@@ -36,8 +35,8 @@ from horizon import exceptions
 from horizon.forms import views
 from horizon import messages
 from horizon import tabs
-from muranoclient.common import exceptions as exc
 
+from muranoclient.common import exceptions as exc
 from muranodashboard import api
 from muranodashboard.api import packages as pkg_api
 from muranodashboard.catalog import tabs as catalog_tabs
@@ -50,7 +49,7 @@ from muranodashboard.environments import consts
 
 LOG = logging.getLogger(__name__)
 ALL_CATEGORY_NAME = 'All'
-LATEST_APPS_QUEUE_LIMIT = 6
+LATEST_APPS_QUEUE_LIMIT = 3
 
 
 class DictToObj(object):
@@ -86,6 +85,16 @@ def get_environments_context(request):
     return context
 
 
+def get_categories_list(request):
+    categories = []
+    with api.handled_exceptions(request):
+        client = api.muranoclient(request)
+        categories = client.packages.categories()
+    if ALL_CATEGORY_NAME not in categories:
+        categories.insert(0, ALL_CATEGORY_NAME)
+    return categories
+
+
 @auth_dec.login_required
 def switch(request, environment_id,
            redirect_field_name=auth.REDIRECT_FIELD_NAME):
@@ -285,9 +294,16 @@ class Wizard(views.ModalFormMixin, LazyWizard):
         fmt = utils.BlankFormatter()
         return fmt.format('{0}_{app_id}', base, **kwargs)
 
+    def get_form_prefix(self, step=None, form=None):
+        if step is None:
+            return self.steps.step0
+        else:
+            index0 = self.steps.all.index(step)
+            return str(index0)
+
     def done(self, form_list, **kwargs):
         app_id = kwargs['app_id']
-        app_name = services.get_service_name(self.request, app_id)
+        app_name = pkg_api.get_service_name(self.request, app_id)
 
         service = form_list[0].service
         attributes = service.extract_attributes()
@@ -350,9 +366,7 @@ class Wizard(views.ModalFormMixin, LazyWizard):
         # that way until we move here from django Wizard to horizon workflow
         if views.ADD_TO_FIELD_HEADER in self.request.META:
             field_id = self.request.META[views.ADD_TO_FIELD_HEADER]
-            response = http.HttpResponse(json.dumps(
-                [obj_id, html.escape(obj_name)]
-            ))
+            response = http.HttpResponse(json.dumps([obj_id, obj_name]))
             response["X-Horizon-Add-To-Field"] = field_id
             return response
         else:
@@ -430,27 +444,34 @@ class IndexView(list_view.ListView):
             query_params = {}
         category = self.get_current_category()
         search = self.request.GET.get('search')
+
         if search:
             query_params['search'] = search
         else:
             if category != ALL_CATEGORY_NAME:
                 query_params['category'] = category
 
+        query_params['order_by'] = self.request.GET.get('order_by', 'name')
+        query_params['sort_dir'] = self.request.GET.get('sort_dir', 'asc')
         return query_params
 
     def get_queryset(self):
         query_params = self.get_query_params(internal_query=True)
         marker = self.request.GET.get('marker')
-        sort_dir = self.request.GET.get('sort_dir')
+
+        sort_dir = query_params['sort_dir']
 
         packages = []
         with api.handled_exceptions(self.request):
+            query_params['catalog'] = True
             packages, self._more = pkg_api.package_list(
                 self.request, filters=query_params, paginate=True,
-                marker=marker, page_size=self.paginate_by, sort_dir=sort_dir)
+                marker=marker, page_size=self.paginate_by, sort_dir=sort_dir,
+                limit=self.paginate_by)
+
+        if self.request.GET.get('sort_dir', 'asc') == 'desc':
+            packages = list(reversed(packages))
 
-        if sort_dir == 'desc':
-            packages.reverse()
         return packages
 
     def get_template_names(self):
@@ -461,6 +482,7 @@ class IndexView(list_view.ListView):
             return self._more
         else:
             query_params = self.get_query_params(internal_query=True)
+            query_params['sort_dir'] = 'asc'
             packages, more = pkg_api.package_list(
                 self.request, filters=query_params, paginate=True,
                 marker=self.get_marker(), page_size=1)
@@ -493,29 +515,23 @@ class IndexView(list_view.ListView):
 
     def prev_page_url(self):
         query_params = self.get_query_params()
-        query_params.update({'marker': self.get_marker(0),
-                             'sort_dir': 'desc'})
+        query_params['marker'] = self.get_marker(0)
+        query_params['sort_dir'] = 'desc'
         return '{0}?{1}'.format(reverse('horizon:murano:catalog:index'),
                                 http_utils.urlencode(query_params))
 
     def next_page_url(self):
         query_params = self.get_query_params()
         query_params['marker'] = self.get_marker()
+        query_params['sort_dir'] = 'asc'
         return '{0}?{1}'.format(reverse('horizon:murano:catalog:index'),
                                 http_utils.urlencode(query_params))
 
     def get_context_data(self, **kwargs):
         context = super(IndexView, self).get_context_data(**kwargs)
 
-        categories = []
-        with api.handled_exceptions(self.request):
-            client = api.muranoclient(self.request)
-            categories = client.packages.categories()
-        if ALL_CATEGORY_NAME not in categories:
-            categories.insert(0, ALL_CATEGORY_NAME)
-
         context.update({
-            'categories': categories,
+            'categories': get_categories_list(self.request),
             'current_category': self.get_current_category(),
             'latest_list': clean_latest_apps(self.request)
         })
@@ -524,6 +540,7 @@ class IndexView(list_view.ListView):
         if search:
             context['search'] = search
 
+        context['tenant_id'] = self.request.session['token'].tenant['id']
         context.update(get_environments_context(self.request))
 
         return context
