@@ -15,27 +15,26 @@
 import copy
 import json
 import logging
+import netaddr
 import re
 
 from django.core.urlresolvers import reverse
 from django.core import validators as django_validator
 from django import forms
+from django.http import Http404
 from django.template import defaultfilters
 from django.template import loader
-from django.utils.encoding import smart_text
-from django.utils import html
 from django.utils.translation import ugettext_lazy as _
 import floppyforms
 from horizon import exceptions
 from horizon import forms as hz_forms
 from horizon import messages
 from horizon import tables
-from muranoclient.common import exceptions as muranoclient_exc
-import netaddr
 from openstack_dashboard.api import glance
 from openstack_dashboard.api import nova
 import yaql
 
+from muranoclient.common import exceptions as muranoclient_exc
 from muranodashboard.api import packages as pkg_api
 from muranodashboard.environments import api as env_api
 from muranodashboard.openstack.common import versionutils
@@ -147,9 +146,6 @@ class RawProperty(object):
         return property(_get, _set, _del)
 
 
-FIELD_ARGS_TO_ESCAPE = ['help_text', 'initial', 'description', 'label']
-
-
 class CustomPropertiesField(forms.Field):
     def __init__(self, description=None, description_title=None,
                  *args, **kwargs):
@@ -157,10 +153,6 @@ class CustomPropertiesField(forms.Field):
         self.description_title = (description_title or
                                   unicode(kwargs.get('label', '')))
 
-        for arg in FIELD_ARGS_TO_ESCAPE:
-            if kwargs.get(arg):
-                kwargs[arg] = html.escape(unicode(kwargs[arg]))
-
         validators = []
         for validator in kwargs.get('validators', []):
             if hasattr(validator, '__call__'):  # single regexpValidator
@@ -211,6 +203,7 @@ class PasswordField(CharField):
     password_re = re.compile('^.*(?=.*\d)(?=.*[a-z])(?=.*[A-Z])(?=.*[%s]).*$'
                              % special_characters)
     has_clone = False
+    original = True
     validate_password = django_validator.RegexValidator(
         password_re, _('The password must contain at least one letter, one   \
                                number and one special character'), 'invalid')
@@ -220,7 +213,7 @@ class PasswordField(CharField):
         return name + '-clone'
 
     def compare(self, name, form_data):
-        if self.is_original() and self.required:
+        if self.original and self.required:
             # run compare only for original fields
             # do not run compare for hidden fields (they are not required)
             if form_data.get(name) != form_data.get(self.get_clone_name(name)):
@@ -261,13 +254,11 @@ class PasswordField(CharField):
         result.error_messages = copy.deepcopy(self.error_messages)
         return result
 
-    def is_original(self):
-        return hasattr(self, 'original') and self.original
-
     def clone_field(self):
         self.has_clone = True
+
         field = copy.deepcopy(self)
-        self.original = True
+        field.original = False
         field.label = _('Confirm password')
         field.error_messages['required'] = _('Please confirm your password')
         field.help_text = _('Retype your password')
@@ -489,6 +480,11 @@ class FlavorChoiceField(ChoiceField):
                 if flavor.ram < self.requirements.get('min_memory_mb', 0):
                     continue
                 self.choices.append((flavor.name, flavor.name))
+        # Search through selected flavors
+        for flavor_name, flavor_name in self.choices:
+            if 'medium' in flavor_name:
+                self.initial = flavor_name
+                break
 
 
 class KeyPairChoiceField(DynamicChoiceField):
@@ -507,7 +503,7 @@ class ImageChoiceField(ChoiceField):
 
     @with_request
     def update(self, request, **kwargs):
-        image_mapping, image_choices = {}, []
+        image_map, image_choices = {}, []
         murano_images = get_murano_images(request)
         for image in murano_images:
             murano_data = image.murano_property
@@ -522,10 +518,10 @@ class ImageChoiceField(ChoiceField):
                 if (not itype.startswith(prefix) and
                         not self.image_type == itype):
                     continue
-            image_mapping[smart_text(title)] = image.name
+            image_map[image.id] = title
 
-        for name in sorted(image_mapping.keys()):
-            image_choices.append((image_mapping[name], name))
+        for id_, title in sorted(image_map.iteritems(), key=lambda e: e[1]):
+            image_choices.append((id_, title))
         if image_choices:
             image_choices.insert(0, ("", _("Select Image")))
         else:
@@ -562,7 +558,6 @@ class BooleanField(forms.BooleanField, CustomPropertiesField):
         else:
             widget = forms.CheckboxInput(attrs={'class': 'checkbox'})
         kwargs['widget'] = widget
-        kwargs['required'] = False
         super(BooleanField, self).__init__(*args, **kwargs)
 
 
@@ -683,6 +678,14 @@ def make_select_cls(fqns):
         fqns = (fqns,)
 
     class Widget(hz_forms.fields.DynamicSelectWidget):
+        def __init__(self, attrs=None, **kwargs):
+            if attrs is None:
+                attrs = {'class': 'murano_add_select'}
+            else:
+                attrs.setdefault('class', '')
+                attrs['class'] += ' murano_add_select'
+            super(Widget, self).__init__(attrs=attrs, **kwargs)
+
         class Media:
             js = ('muranodashboard/js/add-select.js',)
 
@@ -696,8 +699,6 @@ def make_select_cls(fqns):
             else:
                 self.empty_value_message = _('Select Application')
 
-            self.empty_value_message = empty_value_message
-
         @with_request
         def update(self, request, environment_id, **kwargs):
             def _make_link():
@@ -707,7 +708,8 @@ def make_select_cls(fqns):
                     _app = pkg_api.app_by_fqn(request, _fqn)
                     if _app is None:
                         msg = "Application with FQN='{0}' doesn't exist"
-                        raise KeyError(msg.format(_fqn))
+                        messages.error(request, msg.format(_fqn))
+                        raise Http404(msg.format(_fqn))
                     args = (_app.id, environment_id, False, True)
                     return _app.name, reverse(ns_url, args=args)
                 return json.dumps([_reverse(cls) for cls in fqns])
@@ -715,9 +717,12 @@ def make_select_cls(fqns):
             self.widget.add_item_link = _make_link
             apps = env_api.service_list_by_fqns(request, environment_id, fqns)
             choices = [('', self.empty_value_message)]
-            choices.extend([(app['?']['id'],
-                             html.escape(app.name)) for app in apps])
+            choices.extend([(app['?']['id'], app.name) for app in apps])
             self.choices = choices
+            # NOTE(tsufiev): streamline the drop-down UX: auto-select the
+            # single available option in a drop-down
+            if len(choices) == 2:
+                self.initial = choices[1][0]
 
         def clean(self, value):
             value = super(DynamicSelect, self).clean(value)
