@@ -12,21 +12,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import gettext_lazy as _
-from horizon import exceptions
-from oslo_log import log as logging
+import logging
 
 from muranoclient.common import exceptions as exc
 from muranodashboard import api
-from muranodashboard.api import packages as packages_api
 from muranodashboard.common import utils
 from muranodashboard.environments import consts
 from muranodashboard.environments import topology
 
 
-KEY_ERROR_TEMPLATE = _(
-    "Error fetching the environment. The page may be rendered incorrectly. "
-    "Reason: %s")
 LOG = logging.getLogger(__name__)
 
 
@@ -43,8 +37,8 @@ def get_status_messages_for_service(request, service_id, environment_id):
                 environment_id, deployment.id, service_id)
 
             for report in reports:
-                result += (utils.adjust_datestr(request, report.created) +
-                           ' - ' + report.text + '\n')
+                result += report.created.replace('T', ' ') + ' - ' + str(
+                    report.text) + '\n'
     return result
 
 
@@ -59,37 +53,34 @@ def create_session(request, environment_id):
 class Session(object):
     @staticmethod
     def get_or_create(request, environment_id):
-        """Get an open session id
-
-        Gets id from already opened session for specified environment,
-        otherwise opens new session and returns its id
+        """Gets id from already opened session for specified environment,
+        otherwise opens new session and returns it's id
 
         :param request:
         :param environment_id:
         :return: Session Id
         """
-        # We store opened sessions for each environment in dictionary per user
+        #We store opened sessions for each environment in dictionary per user
         sessions = request.session.get('sessions', {})
 
         if environment_id in sessions:
             id = sessions[environment_id]
         else:
-            id = create_session(request, environment_id)
+            id = create_session(environment_id, request)
         return id
 
     @staticmethod
     def get_or_create_or_delete(request, environment_id):
-        """Get an open session id
-
-        Gets id from session in open state for specified environment.
-        If state is deployed, then the session is deleted and a new one
-        is created. If there are no sessions, then a new one is created.
-        Returns id of chosen or created session.
+        """Gets id from session in open state for specified environment,
+        if state is deployed - this session will be deleted and new
+        would be created. If there are no any sessions new would be created.
+        Returns if of chosen or created session.
 
         :param request:
         :param environment_id:
-        :return: Session id
+        :return: Session Id
         """
+
         sessions = request.session.get('sessions', {})
         client = api.muranoclient(request)
 
@@ -99,7 +90,7 @@ class Session(object):
                 session_data = client.sessions.get(environment_id, id)
             except exc.HTTPForbidden:
                 del sessions[environment_id]
-                LOG.debug("The environment is being deployed by other user. "
+                LOG.debug("The environment is being deployed by other user."
                           "Creating a new session "
                           "for the environment {0}".format(environment_id))
                 return create_session(request, environment_id)
@@ -114,43 +105,20 @@ class Session(object):
         else:
             LOG.debug("Creating a new session")
             return create_session(request, environment_id)
-        LOG.debug("Found active session for the environment {0}"
-                  .format(environment_id))
+        LOG.debug("Found active session "
+                  "for the environment {0}".format(environment_id))
         return id
 
-    @staticmethod
-    def get_if_available(request, environment_id):
-        """Get an id of open session if it exists and is not in deployed state.
-
-        Returns None otherwise
-        """
-        sessions = request.session.get('sessions', {})
-        client = api.muranoclient(request)
-
-        if environment_id in sessions:
-            id = sessions[environment_id]
-            try:
-                session_data = client.sessions.get(environment_id, id)
-            except exc.HTTPForbidden:
-                return None
-            else:
-                if session_data.state in [consts.STATUS_ID_DEPLOY_FAILURE,
-                                          consts.STATUS_ID_READY]:
-                    return None
-                return id
-
     @staticmethod
     def get(request, environment_id):
-        """Get an open session id
-
-        Gets id from already opened session for specified environment,
+        """Gets id from already opened session for specified environment,
         otherwise returns None
 
         :param request:
         :param environment_id:
         :return: Session Id
         """
-        # We store opened sessions for each environment in dictionary per user
+        #We store opened sessions for each environment in dictionary per user
         sessions = request.session.get('sessions', {})
         session_id = sessions.get(environment_id, '')
         if session_id:
@@ -161,51 +129,13 @@ class Session(object):
                 environment_id))
         return session_id
 
-    @staticmethod
-    def set(request, environment_id, session_id):
-        """Set an open session id
-
-        sets id from already opened session for specified environment.
-
-        :param request:
-        :param environment_id:
-        :param session_id
-        """
-        # We store opened sessions for each environment in dictionary per user
-        sessions = request.session.get('sessions', {})
-        sessions[environment_id] = session_id
-        request.session['sessions'] = sessions
-
-
-def _update_env(env, request):
-    # TODO(vakovalchuk): optimize latest deployment when limit is available
-    deployments = deployments_list(request, env.id)
-    if deployments:
-        latest_deployment = deployments[0]
-        try:
-            deployed_services = {service['?']['id'] for service in
-                                 latest_deployment.description['services']}
-        except KeyError as e:
-            deployed_services = set()
-            exceptions.handle_recoverable(
-                request, KEY_ERROR_TEMPLATE % e.message)
-    else:
-        deployed_services = set()
 
+def _update_env(env):
+    env.has_new_services = False
     if env.services:
-        try:
-            current_services = {service['?']['id'] for service in env.services}
-        except KeyError as e:
-            current_services = set()
-            exceptions.handle_recoverable(
-                request, KEY_ERROR_TEMPLATE % e.message)
-    else:
-        current_services = set()
-
-    env.has_new_services = current_services != deployed_services
-
-    if not env.has_new_services and env.status == consts.STATUS_ID_PENDING:
-        env.status = consts.STATUS_ID_READY
+        for service in env.services:
+            if service['?']['status'] == 'pending':
+                env.has_new_services = True
 
     if not env.has_new_services and env.version == 0:
         if env.status == consts.STATUS_ID_READY:
@@ -226,20 +156,16 @@ def environments_list(request):
 
 
 def environment_create(request, parameters):
-    # name is required param
+    #name is required param
     body = {'name': parameters['name']}
-    if 'defaultNetworks' in parameters:
-        body['defaultNetworks'] = parameters['defaultNetworks']
     env = api.muranoclient(request).environments.create(body)
     LOG.debug('Environment::Create {0}'.format(env))
     return env
 
 
-def environment_delete(request, environment_id, abandon=False):
-    action = 'Abandon' if abandon else 'Delete'
-    LOG.debug('Environment::{0} <Id : {1}>'.format(action, environment_id))
-    return api.muranoclient(request).environments.delete(
-        environment_id, abandon)
+def environment_delete(request, environment_id):
+    LOG.debug('Environment::Delete <Id: {0}>'.format(environment_id))
+    return api.muranoclient(request).environments.delete(environment_id)
 
 
 def environment_get(request, environment_id):
@@ -248,12 +174,7 @@ def environment_get(request, environment_id):
               format(environment_id, session_id))
     client = api.muranoclient(request)
     env = client.environments.get(environment_id, session_id)
-    acquired = getattr(env, 'acquired_by', None)
-    if acquired and acquired != session_id:
-        env = client.environments.get(environment_id, acquired)
-        Session.set(request, environment_id, acquired)
-
-    env = _update_env(env, request)
+    env = _update_env(env)
 
     LOG.debug('Environment::Get {0}'.format(env))
     return env
@@ -279,17 +200,11 @@ def action_allowed(request, environment_id):
 
 
 def services_list(request, environment_id):
-    """Get environment applications.
-
-       This function collects data from Murano API and modifies it only for
-       dashboard purposes. Those changes don't impact application
-       deployment parameters.
-    """
     def strip(msg, to=100):
-        return u'%s...' % msg[:to] if len(msg) > to else msg
+        return '%s...' % msg[:to] if len(msg) > to else msg
 
     services = []
-    # need to create new session to see services deployed by other user
+    # need to create new session to see services deployed be other user
     session_id = Session.get(request, environment_id)
 
     get_environment = api.muranoclient(request).environments.get
@@ -304,21 +219,16 @@ def services_list(request, environment_id):
 
     for service_item in environment.services or []:
         service_data = service_item
-        try:
-            service_id = service_data['?']['id']
-        except KeyError as e:
-            exceptions.handle_recoverable(
-                request, KEY_ERROR_TEMPLATE % e.message)
-            continue
+        service_id = service_data['?']['id']
 
         if service_id in reports and reports[service_id]:
-            last_operation = strip(reports[service_id].text)
-            time = reports[service_id].updated
+            last_operation = strip(str(reports[service_id].text))
+            time = reports[service_id].updated.replace('T', ' ')
         else:
             last_operation = 'Component draft created' \
                 if environment.version == 0 else ''
             try:
-                time = service_data['updated'][:-7]
+                time = service_data['updated'].replace('T', ' ')[:-7]
             except KeyError:
                 time = None
 
@@ -326,26 +236,6 @@ def services_list(request, environment_id):
         service_data['environment_version'] = environment.version
         service_data['operation'] = last_operation
         service_data['operation_updated'] = time
-        if service_data['?'].get('name'):
-            service_data['name'] = service_data['?']['name']
-        if (consts.DASHBOARD_ATTRS_KEY not in service_data['?'] or
-                not service_data['?'][consts.DASHBOARD_ATTRS_KEY].get('name')):
-            try:
-                fqn = service_data['?']['type']
-            except KeyError as e:
-                exceptions.handle_recoverable(
-                    request, KEY_ERROR_TEMPLATE % e.message)
-                continue
-            version = None
-            if '/' in fqn:
-                version, fqn = fqn.split('/')[1].split('@')
-            pkg = packages_api.app_by_fqn(request, fqn, version=version)
-            if pkg:
-                app_name = pkg.name
-                storage = service_data['?'].setdefault(
-                    consts.DASHBOARD_ATTRS_KEY, {})
-                storage['name'] = app_name
-
         services.append(service_data)
 
     LOG.debug('Service::List')
@@ -357,19 +247,12 @@ def service_list_by_fqns(request, environment_id, fqns):
         return []
     services = services_list(request, environment_id)
     LOG.debug('Service::Instances::List')
-    try:
-        services = [service for service in services
-                    if service['?']['type'].split('/')[0] in fqns]
-    except KeyError as e:
-        services = []
-        exceptions.handle_recoverable(request, KEY_ERROR_TEMPLATE % e.message)
-
-    return services
+    return [service for service in services if service['?']['type'] in fqns]
 
 
 def service_create(request, environment_id, parameters):
-    # We should be able to delete session if we want to add new services to
-    # this environment.
+    # we should be able to delete session
+    # if we what add new services to this environment
     session_id = Session.get_or_create_or_delete(request, environment_id)
     LOG.debug('Service::Create {0}'.format(parameters['?']['type']))
     return api.muranoclient(request).services.post(environment_id,
@@ -389,13 +272,9 @@ def service_delete(request, environment_id, service_id):
 def service_get(request, environment_id, service_id):
     services = services_list(request, environment_id)
     LOG.debug("Return service detail for a specified id")
-    try:
-        for service in services:
-            if service['?']['id'] == service_id:
-                return service
-    except KeyError as e:
-        exceptions.handle_recoverable(request, KEY_ERROR_TEMPLATE % e.message)
-    return None
+    for service in services:
+        if service['?']['id'] == service_id:
+            return service
 
 
 def extract_actions_list(service):
@@ -405,7 +284,7 @@ def extract_actions_list(service):
         return dict(_action.items() + [('id', action_id)])
 
     return [make_action_datum(_id, action) for (_id, action) in
-            iter(actions_data.items()) if action.get('enabled')]
+            actions_data.iteritems() if action.get('enabled')]
 
 
 def run_action(request, environment_id, action_id):
@@ -416,25 +295,16 @@ def run_action(request, environment_id, action_id):
 def deployments_list(request, environment_id):
     LOG.debug('Deployments::List')
     deployments = api.muranoclient(request).deployments.list(environment_id)
+    for deployment in deployments:
+        if deployment.started:
+            deployment.started = deployment.started.replace('T', ' ')
+        if deployment.finished:
+            deployment.finished = deployment.finished.replace('T', ' ')
 
     LOG.debug('Environment::List {0}'.format(deployments))
     return deployments
 
 
-def deployment_history(request):
-    LOG.debug('Deployment::History')
-    deployment_history = api.muranoclient(request).deployments.list(
-        None, all_environments=True)
-
-    for deployment in deployment_history:
-        reports = deployment_reports(request, deployment.environment_id,
-                                     deployment.id)
-        deployment.reports = reports
-
-    LOG.debug('Deployment::History {0}'.format(deployment_history))
-    return deployment_history
-
-
 def deployment_reports(request, environment_id, deployment_id):
     LOG.debug('Deployment::Reports::List')
     reports = api.muranoclient(request).deployments.reports(environment_id,
@@ -448,7 +318,7 @@ def get_deployment_start(request, environment_id, deployment_id):
     LOG.debug('Get deployment start time')
     for deployment in deployments:
         if deployment.id == deployment_id:
-            return utils.adjust_datestr(request, deployment.started)
+            return deployment.started.replace('T', ' ')
     return None
 
 
